@@ -5,7 +5,7 @@ use strict ;
 use App::Framework ;
 
 # VERSION
-our $VERSION = '1.000' ;
+our $VERSION = '1.001' ;
 
 
 	# Create application and run it
@@ -52,6 +52,12 @@ An example of using the application framework with named arguments
 
 src_dir:id backup_dir:id
 
+[OPTIONS]
+
+-database=s	Database name [default=test]
+
+Specify the database name to use
+
 [DESCRIPTION]
 
 B<$name> expects a source directory and destination directory to be specified. If not, then
